@@ -218,7 +218,7 @@ def extract_cmake_and_make_arguments(args):
 
 
 def extract_jobs_flags_values(mflags):
-    """Gets the values of the make jobs flags
+    """Gets the values of tha make jobs flags
 
     :param mflags: string of space separated make arguments
     :type mflags: str
@@ -226,9 +226,9 @@ def extract_jobs_flags_values(mflags):
     :rtype: dict
     """
 
-    regex = r'(?:^|\s)+?(?:-)(j|l)(?:=|(?:\s+?)|$)?(\d*(?:\.\d*)?)?(?!-)' + \
+    regex = r'(?:^|\s)(?:-?(j|l)(\s*[0-9]+|\s|$))' + \
             r'|' + \
-            r'(?:^|\s)+?(?:--)(jobs|load-average)(?:=|(?:\s+?)|$)?(\d*(?:\.\d*)?)?(?!-)'
+            r'(?:^|\s)(?:(?:--)?(jobs|load-average)(?:(?:=|\s+)([0-9]+)|(?:\s|$)))'
 
     jobs_dict = {}
 
@@ -237,9 +237,9 @@ def extract_jobs_flags_values(mflags):
         v = v.strip()
         value = value.strip()
         if k == 'j' or key == 'jobs':
-            jobs_dict['jobs'] = int(v or value) if (v or value) else None
+            jobs_dict['jobs'] = int(v or value) if (v or value) else ''
         elif k == 'l' or key == 'load-average':
-            jobs_dict['load-average'] = float(v or value) if v or value else None
+            jobs_dict['load-average'] = float(v or value)
 
     return jobs_dict
 
@@ -252,17 +252,14 @@ def extract_jobs_flags(mflags):
     :returns: list of make jobs flags
     :rtype: list
     """
-    if not mflags:
-        return []
-    regex = r'(?:^|\s)(-j(?:(?:\s)*(?:\d)*)|\s|$)(?!-)|' + \
-            r'(?:^|\s)(-l(?:(?:\s)*(?:\d*(?:\.\d*)?)|\s|$))(?!-)|' + \
-            r'(?:^|\s)(--jobs(?:(?:=|\s*)(?:\d)*)|\s|$)(?!-)|' + \
-            r'(?:^|\s)(--load-average(?:(?:=|\s*)(?:\d*(?:\.\d*)?)|\s|$))(?!-)'
+    regex = r'(?:^|\s)(-?(?:j|l)(?:\s*[0-9]+|\s|$))' + \
+            r'|' + \
+            r'(?:^|\s)((?:--)?(?:jobs|load-average)(?:(?:=|\s+)[0-9]+|(?:\s|$)))'
     matches = re.findall(regex, mflags) or []
-    matches = [[a for a in m if a][0] for m in matches]
+    matches = [m[0] or m[1] for m in matches]
     filtered_flags = [m.strip() for m in matches] if matches else []
 
-    return filtered_flags or None
+    return filtered_flags
 
 
 def handle_make_arguments(
@@ -288,7 +285,7 @@ def handle_make_arguments(
     # Get the values for the jobs flags which may be in the make args
     jobs_dict = extract_jobs_flags_values(' '.join(make_args))
     jobs_args = extract_jobs_flags(' '.join(make_args))
-    if jobs_args:
+    if len(jobs_args) > 0:
         # Remove jobs flags from cli args if they're present
         make_args = re.sub(' '.join(jobs_args), '', ' '.join(make_args)).split()
 
@@ -335,7 +332,7 @@ def configure_make_args(make_args, jobs_args, use_internal_make_jobserver):
 
     # Get MAKEFLAGS from environment
     makeflags_jobs_flags = extract_jobs_flags(os.environ.get('MAKEFLAGS', ''))
-    using_makeflags_jobs_flags = makeflags_jobs_flags is not None
+    using_makeflags_jobs_flags = len(makeflags_jobs_flags) > 0
     if using_makeflags_jobs_flags:
         makeflags_jobs_flags_dict = extract_jobs_flags_values(' '.join(makeflags_jobs_flags))
         jobs_flags.update(makeflags_jobs_flags_dict)
@@ -383,12 +380,12 @@ def argument_preprocessor(args):
 
     # Extract make jobs flags (these override MAKEFLAGS later on)
     jobs_args = extract_jobs_flags(' '.join(args))
-    if jobs_args:
+    if len(jobs_args) > 0:
         # Remove jobs flags from cli args if they're present
         args = re.sub(' '.join(jobs_args), '', ' '.join(args)).split()
     elif make_args is not None:
         jobs_args = extract_jobs_flags(' '.join(make_args))
-        if jobs_args:
+        if len(jobs_args) > 0:
             # Remove jobs flags from cli args if they're present
             make_args = re.sub(' '.join(jobs_args), '', ' '.join(make_args)).split()
 
