@@ -19,9 +19,8 @@ import errno
 import os
 import re
 import sys
-from fnmatch import fnmatch
 
-import asyncio
+import trollius as asyncio
 
 from shlex import split as _cmd_split
 try:
@@ -64,7 +63,7 @@ class FakeLock(asyncio.locks.Lock):
 
     @asyncio.coroutine
     def acquire(self):
-        return(True)
+        raise asyncio.Return(True)
 
     def release(self):
         pass
@@ -610,6 +609,22 @@ def wide_log(msg, **kwargs):
         pass
 
 
+def get_build_type(package):
+    """Returns the build type for a given package.
+
+    :param package: package object
+    :type package: :py:class:`catkin_pkg.package.Package`
+    :returns: build type of the package, e.g. 'catkin' or 'cmake'
+    :rtype: str
+    """
+    export_tags = [e.tagname for e in package.exports]
+    if 'build_type' in export_tags:
+        build_type_tag = [e.content for e in package.exports if e.tagname == 'build_type'][0]
+    else:
+        build_type_tag = 'catkin'
+    return build_type_tag
+
+
 def find_enclosing_package(search_start_path=None, ws_path=None, warnings=None, symlinks=True):
     """Get the package containing a specific directory.
 
@@ -682,8 +697,3 @@ def parse_env_str(environ_str):
         print('WARNING: Could not parse env string: `{}`'.format(environ_str),
               file=sys.stderr)
         raise
-
-
-def expand_glob_package(pattern, all_workspace_packages):
-    """Return all packages that match the pattern"""
-    return [p for p in all_workspace_packages if fnmatch(p, pattern)]
