@@ -66,10 +66,6 @@ class Context(object):
         'catkin_make_args',
         'whitelist',
         'blacklist',
-        'authors',
-        'maintainers',
-        'licenses',
-        'extends',
     ]
 
     EXTRA_KEYS = [
@@ -194,28 +190,7 @@ class Context(object):
 
         # Get the metadata stored in the workspace if it was found
         if workspace:
-            key_origins = {}
-            visited_profiles = []
-
-            def get_metadata_recursive(profile):
-                config_metadata = metadata.get_metadata(workspace, profile, 'config')
-                visited_profiles.append(profile)
-                if "extends" in config_metadata.keys() and config_metadata["extends"] is not None:
-                    base_profile = config_metadata["extends"]
-                    if base_profile in visited_profiles:
-                        raise IOError("Profile dependency circle detected at dependency from '%s' to '%s'!"
-                                      % (profile, base_profile))
-                    base = get_metadata_recursive(base_profile)
-                    base.update(config_metadata)
-                    for key in config_metadata.keys():
-                        key_origins[key] = profile
-                    return base
-                for key in config_metadata.keys():
-                    key_origins[key] = profile
-                return config_metadata
-
-            config_metadata = get_metadata_recursive(profile)
-
+            config_metadata = metadata.get_metadata(workspace, profile, 'config')
             context_args.update(config_metadata)
 
         # User-supplied args are used to update stored args
@@ -230,14 +205,8 @@ class Context(object):
                         context_args[k] = [w for w in context_args[k] if w not in v]
                     else:
                         context_args[k] = v
-                    if workspace:
-                        key_origins[k] = profile
                 else:
                     context_args[k] = v
-                    if workspace:
-                        key_origins[k] = profile
-
-        context_args["key_origins"] = key_origins
 
         # Create the build context
         ctx = Context(**context_args)
@@ -251,28 +220,11 @@ class Context(object):
     @classmethod
     def save(cls, context):
         """Save a context in the associated workspace and profile."""
-
-        data = context.get_stored_dict()
-        files = {}
-
-        def save_in_file(file, key, value):
-            if file in files.keys():
-                files[file][key] = value
-            else:
-                files[file] = {key: value}
-
-        for key, val in data.items():
-            if key in context.key_origins:
-                save_in_file(context.key_origins[key], key, val)
-            else:
-                save_in_file(context.profile, key, val)
-
-        for profile, content in files.items():
-            metadata.update_metadata(
-                context.workspace,
-                profile,
-                'config',
-                content)
+        metadata.update_metadata(
+            context.workspace,
+            context.profile,
+            'config',
+            context.get_stored_dict())
 
     def get_stored_dict(self):
         """Get the context parameters which should be stored persistently."""
@@ -295,11 +247,6 @@ class Context(object):
         space_suffix=None,
         whitelist=None,
         blacklist=None,
-        authors=None,
-        maintainers=None,
-        licenses=None,
-        extends=None,
-        key_origins={},
         **kwargs
     ):
         """Creates a new Context object, optionally initializing with parameters
@@ -345,14 +292,6 @@ class Context(object):
         :param blacklist: a list of packages to ignore by default
         :type blacklist: list
         :raises: ValueError if workspace or source space does not exist
-        :type authors: list
-        :param authors: a list of default authors
-        :type maintainers: list
-        :param maintainers: a list of default maintainers
-        :type licenses: list
-        :param licenses: a list of default licenses
-        :type extends: string
-        :param extends: the name of a profile to use as a base and inherit settings from
         """
         self.__locked = False
 
@@ -360,7 +299,6 @@ class Context(object):
         self.workspace = workspace
 
         self.extend_path = extend_path if extend_path else None
-        self.key_origins = key_origins
 
         self.profile = profile
 
@@ -368,10 +306,9 @@ class Context(object):
         for space, space_dict in Context.SPACES.items():
             key_name = space + '_space'
             default = space_dict['default']
-            value = kwargs.pop(key_name, default)
-            if value == default and space_suffix and space != 'source':
-                value += space_suffix
-            setattr(self, key_name, value)
+            if space_suffix and space != 'source':
+                default += space_suffix
+            setattr(self, key_name, kwargs.pop(key_name, default))
 
         # Check for unhandled context options
         if len(kwargs) > 0:
@@ -383,11 +320,6 @@ class Context(object):
         self.whitelist = whitelist or []
         self.blacklist = blacklist or []
 
-        # Handle default authors/maintainers
-        self.authors = authors or []
-        self.maintainers = maintainers or []
-        self.licenses = licenses or 'TODO'
-
         # Handle build options
         self.devel_layout = devel_layout if devel_layout else 'linked'
         self.install = install
@@ -413,8 +345,6 @@ class Context(object):
         self.env_cmake_prefix_path = None
         self.cmake_prefix_path = None
 
-        self.extends = extends
-
     def load_env(self):
 
         # Check for CMAKE_PREFIX_PATH in manual cmake args
@@ -800,38 +730,6 @@ class Context(object):
     def blacklist(self, value):
         self.__blacklist = value
 
-    @property
-    def authors(self):
-        return self.__authors
-
-    @authors.setter
-    def authors(self, value):
-        self.__authors = value
-
-    @property
-    def maintainers(self):
-        return self.__maintainers
-
-    @maintainers.setter
-    def maintainers(self, value):
-        self.__maintainers = value
-
-    @property
-    def licenses(self):
-        return self.__licenses
-
-    @licenses.setter
-    def licenses(self, value):
-        self.__licenses = value
-
-    @property
-    def extends(self):
-        return self.__extends
-
-    @extends.setter
-    def extends(self, value):
-        self.__extends = value
-
     @property
     def private_devel_path(self):
         """The path to the hidden directory in the develspace that
