@@ -20,7 +20,6 @@ except ImportError:
     from Queue import Empty
 
 import math
-import itertools
 import sys
 import threading
 import time
@@ -285,7 +284,7 @@ class ConsoleStatusController(threading.Thread):
         ])
 
         # Calculate the number of columns
-        number_of_columns = int((terminal_width() / max_column_len) or 1)
+        number_of_columns = (terminal_width() / max_column_len) or 1
 
         # Construct different categories of jobs (jid -> output template)
         successfuls = {}
@@ -320,7 +319,7 @@ class ConsoleStatusController(threading.Thread):
             wide_log(clr("[{}] Successful {}:").format(self.label, self.jobs_label))
             wide_log("")
             print_items_in_columns(
-                sorted(itertools.chain(successfuls.items(), ignoreds.items())),
+                sorted(successfuls.items() + ignoreds.items()),
                 number_of_columns)
         else:
             wide_log("")
@@ -695,8 +694,9 @@ class ConsoleStatusController(threading.Thread):
                 if self.show_buffered_stdout:
                     if len(event.data['interleaved']) > 0:
                         lines = [
-                            line for line in event.data['interleaved'].splitlines(True)
-                            if (self.show_compact_io is False or len(line.strip()) > 0)
+                            l
+                            for l in event.data['interleaved'].splitlines(True)
+                            if (self.show_compact_io is False or len(l.strip()) > 0)
                         ]
                     else:
                         header_border = None
@@ -705,8 +705,9 @@ class ConsoleStatusController(threading.Thread):
                 elif self.show_buffered_stderr:
                     if len(event.data['stderr']) > 0:
                         lines = [
-                            line for line in event.data['stderr'].splitlines(True)
-                            if (self.show_compact_io is False or len(line.strip()) > 0)
+                            l
+                            for l in event.data['stderr'].splitlines(True)
+                            if (self.show_compact_io is False or len(l.strip()) > 0)
                         ]
                         lines_target = sys.stderr
                     else:
@@ -766,4 +767,4 @@ class ConsoleStatusController(threading.Thread):
         template = '\r{}\r{}'.format(' ' * terminal_width(), prefix)
         suffix = clr('@|')
 
-        return ''.join(template + line + suffix for line in data['data'].splitlines(True))
+        return ''.join(template + l + suffix for l in data['data'].splitlines(True))
