@@ -16,12 +16,13 @@
 
 import os
 import pkg_resources
+import stat
 import sys
 import time
 import traceback
 import yaml
 
-import asyncio
+import trollius as asyncio
 
 try:
     # Python3
@@ -41,8 +42,9 @@ except ImportError as e:
 
 from catkin_pkg.package import parse_package
 
-from catkin_tools.common import FakeLock, expand_glob_package
+from catkin_tools.common import FakeLock
 from catkin_tools.common import format_time_delta
+from catkin_tools.common import get_build_type
 from catkin_tools.common import get_cached_recursive_build_depends_in_workspace
 from catkin_tools.common import get_recursive_run_depends_in_workspace
 from catkin_tools.common import log
@@ -90,20 +92,13 @@ def determine_packages_to_be_built(packages, context, workspace_packages):
     packages_to_be_built = []
     packages_to_be_built_deps = []
 
-    workspace_package_names = dict([(pkg.name, (path, pkg)) for path, pkg in ordered_packages])
     # Determine the packages to be built
     if packages:
         # First assert all of the packages given are in the workspace
+        workspace_package_names = dict([(pkg.name, (path, pkg)) for path, pkg in ordered_packages])
         for package in packages:
             if package not in workspace_package_names:
-                # Try whether package is a pattern and matches
-                glob_packages = expand_glob_package(package, workspace_package_names)
-                if len(glob_packages) > 0:
-                    packages.extend(glob_packages)
-                    continue
-                else:
-                    sys.exit("[build] Given package '{0}' is not in the workspace"
-                             "and pattern does not match any package".format(package))
+                sys.exit("[build] Given package '{0}' is not in the workspace".format(package))
             # If metapackage, include run depends which are in the workspace
             package_obj = workspace_package_names[package][1]
             if 'metapackage' in [e.tagname for e in package_obj.exports]:
@@ -120,27 +115,19 @@ def determine_packages_to_be_built(packages, context, workspace_packages):
     else:
         # Only use whitelist when no other packages are specified
         if len(context.whitelist) > 0:
-            # Expand glob patterns in whitelist
-            whitelist = []
-            for whitelisted_package in context.whitelist:
-                whitelist.extend(expand_glob_package(whitelisted_package, workspace_package_names))
-            packages_to_be_built = [p for p in ordered_packages if (p[1].name in whitelist)]
+            packages_to_be_built = [p for p in ordered_packages if (p[1].name in context.whitelist)]
         else:
             packages_to_be_built = ordered_packages
 
     # Filter packages with blacklist
     if len(context.blacklist) > 0:
-        # Expand glob patterns in blacklist
-        blacklist = []
-        for blacklisted_package in context.blacklist:
-            blacklist.extend(expand_glob_package(blacklisted_package, workspace_package_names))
-        # Apply blacklist to packages and dependencies
         packages_to_be_built = [
             (path, pkg) for path, pkg in packages_to_be_built
-            if (pkg.name not in blacklist or pkg.name in packages)]
+            if (pkg.name not in context.blacklist or pkg.name in packages)]
         packages_to_be_built_deps = [
             (path, pkg) for path, pkg in packages_to_be_built_deps
-            if (pkg.name not in blacklist or pkg.name in packages)]
+            if (pkg.name not in context.blacklist or pkg.name in packages)]
+        ordered_packages = ordered_packages
 
     return packages_to_be_built, packages_to_be_built_deps, ordered_packages
 
@@ -166,8 +153,9 @@ def get_built_unbuilt_packages(context, workspace_packages):
     # Get names of all unbuilt packages
     unbuilt_pkgs = set()
     for path, pkg in workspace_packages.items():
-        if pkg.name not in built_packages:
-            unbuilt_pkgs.add(pkg.name)
+        if 'metapackage' not in [e.tagname for e in pkg.exports]:
+            if pkg.name not in built_packages:
+                unbuilt_pkgs.add(pkg.name)
 
     return built_packages, unbuilt_pkgs
 
@@ -279,10 +267,9 @@ def build_isolated_workspace(
     if os.path.exists(context.build_space_abs):
         if os.path.isfile(context.build_space_abs):
             sys.exit(clr(
-                "[build] @{rf}Error:@| " +
-                "Build space '{0}' exists but is a file and not a folder."
+                "[build] @{rf}Error:@| Build space '{0}' exists but is a file and not a folder."
                 .format(context.build_space_abs)))
-    # If it doesn't exist, create it
+    # If it dosen't exist, create it
     else:
         log("[build] Creating build space: '{0}'".format(context.build_space_abs))
         os.makedirs(context.build_space_abs)
@@ -479,7 +466,11 @@ def build_isolated_workspace(
         if pkg.name not in packages_to_be_built_names:
             continue
 
-        # Get actual build deps
+        # Ignore metapackages
+        if 'metapackage' in [e.tagname for e in pkg.exports]:
+            continue
+
+        # Get actual execution deps
         deps = [
             p.name for _, p
             in get_cached_recursive_build_depends_in_workspace(pkg, packages_to_be_built)
@@ -500,7 +491,7 @@ def build_isolated_workspace(
             pre_clean=pre_clean)
 
         # Create the job based on the build type
-        build_type = pkg.get_build_type()
+        build_type = get_build_type(pkg)
 
         if build_type in build_job_creators:
             jobs.append(build_job_creators[build_type](**build_job_kwargs))
@@ -641,16 +632,19 @@ def _create_unmerged_devel_setup(context, unbuilt):
     )
     with open(setup_sh_path, 'w') as f:
         f.write(env_file)
+    os.chmod(setup_sh_path, stat.S_IXUSR | stat.S_IWUSR | stat.S_IRUSR)
 
     # Create setup.bash file
     setup_bash_path = os.path.join(context.devel_space_abs, 'setup.bash')
     with open(setup_bash_path, 'w') as f:
         f.write(SETUP_BASH_TEMPLATE)
+    os.chmod(setup_bash_path, stat.S_IXUSR | stat.S_IWUSR | stat.S_IRUSR)
 
     # Create setup.zsh file
     setup_zsh_path = os.path.join(context.devel_space_abs, 'setup.zsh')
     with open(setup_zsh_path, 'w') as f:
         f.write(SETUP_ZSH_TEMPLATE)
+    os.chmod(setup_zsh_path, stat.S_IXUSR | stat.S_IWUSR | stat.S_IRUSR)
 
 
 def _create_unmerged_devel_setup_for_install(context):
